Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: build.gradle

Issue 29782630: Issue 6000 - Rename "libadblockplus-android" (Closed)
Patch Set: Created May 15, 2018, 9:30 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « adblock-android/src/org/adblockplus/libadblockplus/android/Utils.java ('k') | dependencies » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build.gradle
===================================================================
--- a/build.gradle
+++ b/build.gradle
@@ -1,12 +1,12 @@
import java.util.regex.Matcher
import java.util.regex.Pattern
// ABI flavor of "libadblockplus-android" module
def getAbiFlavor() {
Gradle gradle = getGradle()
String taskReqStr = gradle.getStartParameter().getTaskRequests().toString()
Pattern pattern;
if (taskReqStr.contains("assemble")) {
pattern = Pattern.compile("assemble(Abi_\\w{2,3})(Release|Debug)*(\\w*)")
@@ -41,9 +41,9 @@
buildDir = "${gradleBuildDir}/${project.name}"
}
}
subprojects {
task listAllDependencies(type: DependencyReportTask) {}
}
-println "[Configuration] Using libadblockplus-android ABI flavor: " + getAbiFlavor()
+println "[Configuration] Using adblock-android ABI flavor: " + getAbiFlavor()
« no previous file with comments | « adblock-android/src/org/adblockplus/libadblockplus/android/Utils.java ('k') | dependencies » ('j') | no next file with comments »

Powered by Google App Engine
@@ -1,12 +1,12 @@
import java.util.regex.Matcher
import java.util.regex.Pattern
-// ABI flavor of "libadblockplus-android" module
+// ABI flavor of "adblock-android" module
def getAbiFlavor() {
Gradle gradle = getGradle()
This is Rietveld